#
# spec file for package guvcview-qt5
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Malcolm J Lewis <malcolmlewis@opensuse.org>
# Copyright (c) 2013 Marguerite Su <marguerite@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         sover 2_0-2

Name:           guvcview-qt5
Version:        2.0.5
Release:        lp150.1.9
# Reference to GPL-2.0 in some files?
Summary:        Qt5 UVC Viewer and Capturer
License:        GPL-3.0
Group:          Productivity/Multimedia/Video/Players
Url:            http://guvcview.sourceforge.net/
Source0:        http://sourceforge.net/projects/guvcview/files/source/guvcview-src-%{version}.tar.gz
Source90:       pre_checkin.sh
# PATCH-FIX-OPENSUSE guvcview-SUSE.patch -- use SUSE-specific paths
Patch0:         guvcview-SUSE.patch
# PATCH-FIX-OPENSUSE guvcview-qt5-nolibs_qt5names.patch -- use libraries from the GTK+ package
Patch1:         guvcview-qt5-nolibs_qt5names.patch
# PATCH-FIX-UPSTREAM guvcview-qt5-ppc64_QVariant.patch -- fix conversion bug on ppc64
Patch2:         guvcview-qt5-ppc64_QVariant.patch
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  guvcview-devel = %{version}
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Widgets)
Recommends:     %{name}-lang

%description
A Qt5 interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%lang_package

%prep
%setup -q -n guvcview-src-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
autoreconf -fiv
%configure --disable-debian-menu \
	   --disable-desktop \
           --disable-gtk3 \
           --enable-qt5 \
           --program-suffix=-qt5

make %{?_smp_mflags}

%install
%make_install
# Create desktop file as disabled during build
%suse_update_desktop_file -c %{name} "A video viewer and capturer for the linux uvc driver" %{name} %{name} %{name} AudioVideo AudioVideoEditing
%fdupes %{buildroot}

%find_lang %{name} %{?no_lang_C}

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man1/%{name}.1%{ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Sep 11 2017 jengelh@inai.de
- Update summary of -devel subpackage.
* Sat Jul 29 2017 aloisio@gmx.com
- Update to version 2.0.5
  * terminate configure if qt5 is enabled and moc is missing
  * add sfml render
  * fix aac encoder (replace experimental aac by libvo_aacenc)
  * fix build against newer kernels
  * disable window key pressed events if a string control has focus
  * fix video monotonic pts flag value in encoder context
  * fix audio cleanup
  * add support for HEVC (h265) video codec
  * fix muxed h264 support; fix raw output (alloc outbuf frame)
  * add circular buffer for delayed audio frames pts
  * remove support for older libavcodec versions (< 54.01)
  * add support for VP9
  * fix motion estimation method for x264 [1-4]
  * fix buggy behaviour for file names without extension
  * add support for sfml render
  * drop support for sdl1 based render
  * Flavio Spagnuolo <flavio.spagnuolo@gmail.com>: fix matroska
    clean up when audio is disabled
  * fix segfault when destroying mutexes by unlocking already
    unlocked mutexes
  * fix libc readdir_r deprecated warning: replace by readdir
  * add extra video fx filters
- Dropped guvcview-2.0.4_ffmpeg-3.0.patch (merged upstream)
- Split lang package contents between guvcview-lang and a new
  libgviewv4l2core-lang
- Added separate -qt5 and -qt5-lang packages and pre_checkin.sh
  and guvcview-qt5-nolibs_qt5names.patch to support them
- Added guvcview-qt5-ppc64_QVariant.patch to fix build on ppc64
- Replaced some in-spec commands with guvcview-SUSE.patch
* Thu Mar  2 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use
- Ensure description neutrality
* Sun May  1 2016 aloisio@gmx.com
- Update to version 2.0.4:
  * drop support for internal 422 packed format (use only 420 planar)
  * add support for extra pixel formats, including be formats
  * add command line option for requesting fps
  * add support for control events
  * add support for string, int64, bitmask and integer menu controls
  * make sure we can't select unsuported pix formats from the gui
  * fix status message for QT5 interface
  * move mutexes to device handlers (context)
  * v4l2core and audio api - don't access device data directly (use opaque structures)
  * add constructor and destructor functions for v4l2core and encoder
    Paulo Assis <pj.assis@gmail.com> Mon, 22 Feb 2016 10:10:00 +0100
  2.0.3:
  * Add Qt5 interface (--enable-qt5)
  * fix '-n' option (don't save frame when photo countdown reaches 0)
  * restore exit_on_term option
  * use AC_SYS_LARGEFILE m4 macro for enabling Large File Support (LFS) on 32 bit systems
  * add color config for crosshair osd
  * change rendering engine to use updateTexture instead of lock/unlock texture
  * change rendering lib to avoid frame copy when using osd
    Paulo Assis <pj.assis@gmail.com> Mon, 4 Jan 2016 23:34:00 +0100
- Dropped guvcview-implicit-pointer-decl.patch
  guvcview-no-return-in-nonvoid-function.patch
  guvcview-voidreturn.patch
- Added guvcview-2.0.4_ffmpeg-3.0.patch
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Wed Aug  5 2015 joerg.lorenzen@ki.tng.de
- Update to version 2.0.2:
  + fix mjpeg and h264 decoders (libav): init avpacket.
  + fix wrong logic of enable switches (Marvin Schmidt  ticket #12).
  + create a frame queue and refactor frame grab/decode.
  + fix jpeg decoder for older libavcodec api ( < 54.25).
  + attach video capture to SIGUSR1 signal.
  + add audio latency control to gui.
  + change default portaudio latency to high latency.
  + set device during initialization.
  + use time for matroska segment uid if gsl is disabled.
  + fix array index causing buffer overflow.
  + restore CPPFLAGS after AC_CHECK_HEADERS.
  + remove direct access to device data in v4l2core lib.
  + make sure to stop encoder thread before exiting capture thread.
  + avoid SIGFPE on bad channels or samprate data inside audio
    capture callbacks.
  + remove check for avcodec.h (it's needed for very old libavcodec
    versions); set iyuv as default internal format (over yuyv).
  + add basic support for continuous and stepwise frame sizes.
  + add support for empty control list.
  + add code for crossair osd.
  + fix h264 demux from mjpg container.
  + fix pan/tilt for logitech peripheral V3 (use raw control
    instead of v4l2).
* Fri Oct 31 2014 joerg.lorenzen@ki.tng.de
- Update to version 2.0.1:
  + Fix audio clean bug (segfault when audio=none).
  + Add --disable_libv4l2 option.
  + Add support for internal yu12 planar format.
  + Workaround uvcvideo bug (buf.bytesused=0 on kernels >=3.16).
- Changes since version 2.0.0:
  + New version 2.0.0 (code rewriten from scratch).
  + Move all core functions to 4 shared libs.
  + Change options.
  + Change config.
  + Add sdl2 render.
  + Use gsl for random number generation.
- Changes since version 1.7.3:
  + Add silence frames to compensate audio drift (delay).
  + Fix possible memory leak.
  + Add video and image capture through system signals:
    SIGUSR1 and SIGUSR2.
  + Add true no_display mode (no X required).
  + Small bug fixes.
- Changes since version 1.7.2:
  + Add H264 decoding support.
  + Sync translations.
- Changes since version 1.7.1:
  + Fix avi muxer: fix opendml indexes (>= 1Gb).
  + Update Italian translation.
* Tue Jul 30 2013 i@margueirte.su
- build against libffmpeg-devel.
* Sat Jul 20 2013 zaitor@opensuse.org
- Update to version 1.7.0:
  + Refactor avi muxer (base it on libav muxer with opendml
    support).
  + Refactor mkv muxer (base it on libav muxer with webm support).
  + Add VP8, Theora and Vorbis codecs.
  + Add Webm support.
  + Add a Top Menu.
  + Move all file operations to the Top Menu.
* Thu Sep 20 2012 zaitor@opensuse.org
- Update to version 1.6.1:
  + Fix build with latest libavcodec.
  + Fix audio codecs listing.
  + Fix audio codecs (AC3 and AAC) input format for latest
    libavcodec API (float).
  + Add support for delayed frames in video encoding.
- Changes since version 1.6.0:
  + Run audio in separate thread.
  + Update audio buffer.
  + Move pulse audio interface from simple to async API.
  + Add pulse device list.
  + Enable build of pulse API by default.
- Added new build dependency, intltool.
* Sun May 20 2012 zaitor@opensuse.org
- Update to version 1.5.3:
  + Update libavcodec API.
  + Add libavutil dependency.
  + Fix pulse interface.
  + Update language catalogs.
- Drop guvcview-pulseaudio-fix.patch, fixed upstream.
- Change BuildRequires: pulseaudio-devel to libpulse-devel.
* Sun Feb 26 2012 zaitor@opensuse.org
- Update to version 1.5.2:
  + Move to pthreads (fix gthread API 2 issues).
  + Add italian translation.
  + Fix several libavcodec issues.
  + Fix some gtk3 widgets.
- Drop guvcview-fix-glib-include.patch, fixed upstream.
- Add guvcview-pulseaudio-fix.patch: Fix pulseaudio interface.
* Mon Jan 23 2012 malcolmlewis@opensuse.org
- Updated to version 1.5.1:
  + Moved to gtk3.
  + Make control window size dependent on screen resolution.
  + Threaded coding patch - George Sedov <radist.morse@gmail.com>.
  + Fix h264 codec properties.
- Updates from version 1.5.0:
  + Add a no display mode (--no_display).
  + Fix build issues with newer versions (>=0.7.x) of ffmpeg
    libavcodec.
  + Add support for unix signals.
  + Add VU meter OSD.
  + Fix menu controls (linux 3.0).
- Add guvcview-fix-glib-include.patch: To fix only <glib.h> can be
  included directly error for builds > 1210.
* Mon Oct  3 2011 malcolmlewis@opensuse.org
- Fix guvcview.desktop file in spec file.
* Fri Jul  1 2011 malcolmlewis@opensuse.org
- Initial build based on fc15 spec file.
